@@ -16,6 +16,12 @@ try:
 except ImportError:
     pass
 
+try:
+    from chaussette.backend import _tornado
+    _backends['tornado'] = _tornado.Server
+except ImportError:
+    pass
+
 
 PY3 = sys.version_info[0] == 3
 
@@ -53,6 +59,12 @@ if not PY3:
     except ImportError:
         pass
 
+    try:
+        from chaussette.backend import _bjoern
+        _backends['bjoern'] = _bjoern.Server
+    except ImportError:
+        pass
+
 
 def register(name, server):
     _backends[name] = server
